==> nextcloud-app-deck-1%3A1.15.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/az.js <==
OC.L10N.register(
    "deck",
    {
    "The file was uploaded" : "Fayl yükləndi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklənmiş fayl php.ini-də upload_max_filesize direktivini aşır",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklənilən faylın həcmi HTML formasinda olan MAX_FILE_SIZE direktivində təyin dilmiş həcmi aşır.",
    "The file was only partially uploaded" : "Fayl yalnız qismən yüklənib",
    "No file was uploaded" : "Heç bir fayl yüklənilmədi",
    "Missing a temporary folder" : "Müvəqqəti qovluq çatışmır",
    "Could not write file to disk" : "Faylı diskə yazmaq mümkün olmadı",
    "A PHP extension stopped the file upload" : "PHP uzantısı faylın yüklənməsini dayandırdı",
    "Finished" : "Bitdi",
    "Done" : "Done",
    "Cancel" : "Dayandır",
    "Completed" : "Bitmişdir",
    "Details" : "Detallar",
    "Sharing" : "Paylaşılır",
    "Tags" : "Işarələr",
    "Activity" : "Fəallıq",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Sil",
    "Edit" : "Dəyişiklik et",
    "Download" : "Yüklə",
    "Modified" : "Dəyişdirildi",
    "Comments" : "Şərhlər",
    "Save" : "Saxla",
    "Created:" : "Yaradıldı:",
    "Reply" : "Cavab",
    "Update" : "Yenilənmə",
    "Description" : "Açıqlanma",
    "(group)" : "(qrup)",
    "seconds ago" : "saniyələr öncə",
    "Search" : "Axtarış",
    "Shared with you" : "Shared with you",
    "Export" : "Çıxarış",
    "Today" : "Bu gün",
    "Tomorrow" : "Sabah",
    "Close" : "Bağla",
    "Share" : "Paylaş",
    "Personal" : "Şəxsi"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.16.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/az.js <==
OC.L10N.register(
    "deck",
    {
    "The file was uploaded" : "Fayl yükləndi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklənmiş fayl php.ini-də upload_max_filesize direktivini aşır",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklənilən faylın həcmi HTML formasinda olan MAX_FILE_SIZE direktivində təyin dilmiş həcmi aşır.",
    "The file was only partially uploaded" : "Fayl yalnız qismən yüklənib",
    "No file was uploaded" : "Heç bir fayl yüklənilmədi",
    "Missing a temporary folder" : "Müvəqqəti qovluq çatışmır",
    "Could not write file to disk" : "Faylı diskə yazmaq mümkün olmadı",
    "A PHP extension stopped the file upload" : "PHP uzantısı faylın yüklənməsini dayandırdı",
    "Finished" : "Bitdi",
    "Done" : "Done",
    "Cancel" : "Dayandır",
    "Completed" : "Bitmişdir",
    "Details" : "Detallar",
    "General" : "Ümumi",
    "Search" : "Axtarış",
    "Sharing" : "Paylaşılır",
    "Tags" : "Işarələr",
    "Activity" : "Fəallıq",
    "Can edit" : "Can edit",
    "Can share" : "Can share",
    "Owner" : "Owner",
    "Delete" : "Sil",
    "Edit" : "Dəyişiklik et",
    "Download" : "Yüklə",
    "Modified" : "Dəyişdirildi",
    "Comments" : "Şərhlər",
    "Created:" : "Yaradıldı:",
    "Reply" : "Cavab",
    "Update" : "Yenilənmə",
    "Description" : "Açıqlanma",
    "(group)" : "(qrup)",
    "seconds ago" : "saniyələr öncə",
    "Shared with you" : "Shared with you",
    "Export" : "Çıxarış",
    "Close" : "Bağla",
    "Share" : "Paylaş",
    "Personal" : "Şəxsi",
    "Save" : "Saxla",
    "Today" : "Bu gün",
    "Tomorrow" : "Sabah"
},
"nplurals=2; plural=(n != 1);");
